@@ -6,25 +6,26 @@
 #' @return
 #' Returns a matrix of class \code{dgCMatrix}. 
 #' @examples
+#' \dontrun{
 #' a_matrix <- Matrix::Matrix(0, nrow=10, ncol=10)
 #' 
 #' a_list <- list(a_matrix, a_matrix, a_matrix, a_matrix, a_matrix)
 #' 
 #' result <- RecursiveRbind(a_list)
-#' 
+#' }
 #' @export 
 
 RecursiveRbind <- function(matrix_list){
-  
+  .Deprecated("Matrix::rbind2")
   if(length(matrix_list) <= 100){
     
-    return(do.call(Matrix::rBind, matrix_list))
+    return(do.call(Matrix::rbind2, matrix_list))
     
   }else{
     batches <- seq(1, length(matrix_list), by = 100)
     
     matrix_list <- lapply(batches, function(x){
-      do.call(Matrix::rBind, matrix_list[ x:min(x + 99, length(matrix_list))])
+      do.call(Matrix::rbind2, matrix_list[ x:min(x + 99, length(matrix_list))])
     })
     
     RecursiveRbind(matrix_list=matrix_list)
